@@ -27,6 +27,7 @@ from moodle_dl.state_recorder.file import File
 from moodle_dl.state_recorder.course import Course
 from moodle_dl.download_service.path_tools import PathTools
 from moodle_dl.moodle_connector.request_helper import RequestHelper
+from moodle_dl.ydl_extractors.extractors import add_additional_extractors
 
 
 class URLTarget(object):
@@ -441,6 +442,7 @@ class URLTarget(object):
                 ydl_opts.update({'cookiefile': cookies_path})
 
             ydl = youtube_dl.YoutubeDL(ydl_opts)
+            add_additional_extractors(ydl)
             try:
                 ydl_results = ydl.download([url_to_download])
                 if ydl_results == 1:
